==> moodle-1.6.3p0.tgz: moodle/lang/en_utf8/currencies.php <==
<?php // $Id: currencies.php,v 1.1 2006/02/06 09:28:54 moodler Exp $ 
      // currencies.php - created with Moodle 1.5.2 (2005060220)

$string['ADP'] = 'Andorran Peseta';
$string['AED'] = 'United Arab Emirates Dirham';
$string['AFA'] = 'Afghanistan Afghani';
$string['ALL'] = 'Albanian Lek';
$string['ANG'] = 'Netherlands Antillian Guilder';
$string['AOK'] = 'Angolan Kwanza';
$string['ARA'] = 'Argentinian Austral';
$string['ATS'] = 'Austrian Schilling';
$string['AUD'] = 'Australian Dollar';
$string['AWG'] = 'Aruban Florin';
$string['BBD'] = 'Barbados Dollar';
$string['BDT'] = 'Bangladeshi Taka';
$string['BEF'] = 'Belgian Franc';
$string['BGL'] = 'Bulgarian Lev';
$string['BHD'] = 'Bahraini Dinar';
$string['BIF'] = 'Burundi Franc';
$string['BMD'] = 'Bermudian Dollar';
$string['BND'] = 'Brunei Dollar';
$string['BOB'] = 'Bolivian Boliviano';
$string['BRC'] = 'Brazilian Cruzeiro';
$string['BSD'] = 'Bahamian Dollar';
$string['BTN'] = 'Bhutan Ngultrum';
$string['BUK'] = 'Burma Kyat';
$string['BWP'] = 'Botswanian Pula';
$string['BZD'] = 'Belize Dollar';
$string['CAD'] = 'Canadian Dollar';
$string['CHF'] = 'Swiss Franc';
$string['CLF'] = 'Chilean Unidades de Fomento';
$string['CLP'] = 'Chilean Peso';
$string['CNY'] = 'Yuan (Chinese) Renminbi';
$string['COP'] = 'Colombian Peso';
$string['CRC'] = 'Costa Rican Colon';
$string['CSK'] = 'Czech Koruna';
$string['CUP'] = 'Cuban Peso';
$string['CVE'] = 'Cape Verde Escudo';
$string['CYP'] = 'Cyprus Pound';
$string['DDM'] = 'East German Mark (DDR)';
$string['DEM'] = 'Deutsche Mark';
$string['DJF'] = 'Djibouti Franc';
$string['DKK'] = 'Danish Krone';
$string['DOP'] = 'Dominican Peso';
$string['DZD'] = 'Algerian Dinar';
$string['ECS'] = 'Ecuador Sucre';
$string['EGP'] = 'Egyptian Pound';
$string['ESP'] = 'Spanish Peseta';
$string['ETB'] = 'Ethiopian Birr';
$string['EUR'] = 'Euro';
$string['FIM'] = 'Finnish Markka';
$string['FJD'] = 'Fiji Dollar';
$string['FKP'] = 'Falkland Islands Pound';
$string['FRF'] = 'French Franc';
$string['GBP'] = 'British Pound';
$string['GHC'] = 'Ghanaian Cedi';
$string['GIP'] = 'Gibraltar Pound';
$string['GMD'] = 'Gambian Dalasi';
$string['GNF'] = 'Guinea Franc';
$string['GRD'] = 'Greek Drachma';
$string['GTQ'] = 'Guatemalan Quetzal';
$string['GWP'] = 'Guinea-Bissau Peso';
$string['GYD'] = 'Guyanan Dollar';
$string['HKD'] = 'Hong Kong Dollar';
$string['HNL'] = 'Honduran Lempira';
$string['HTG'] = 'Haitian Gourde';
$string['HUF'] = 'Hungarian Forint';
$string['IDR'] = 'Indonesian Rupiah';
$string['IEP'] = 'Irish Punt';
$string['ILS'] = 'Israeli Shekel';
$string['INR'] = 'Indian Rupee';
$string['IQD'] = 'Iraqi Dinar';
$string['IRR'] = 'Iranian Rial';
$string['ISK'] = 'Iceland Krona';
$string['ITL'] = 'Italian Lira';
$string['JMD'] = 'Jamaican Dollar';
$string['JOD'] = 'Jordanian Dinar';
$string['JPY'] = 'Japanese Yen';
$string['KES'] = 'Kenyan Schilling';
$string['KHR'] = 'Kampuchean (Cambodian) Riel';
$string['KMF'] = 'Comoros Franc';
$string['KPW'] = 'North Korean Won';
$string['KRW'] = 'South Korean Won';
$string['KWD'] = 'Kuwaiti Dinar';
$string['KYD'] = 'Cayman Islands Dollar';
$string['LAK'] = 'Lao Kip';
$string['LBP'] = 'Lebanese Pound';
$string['LKR'] = 'Sri Lanka Rupee';
$string['LRD'] = 'Liberian Dollar';
$string['LSL'] = 'Lesotho Loti';
$string['LUF'] = 'Luxembourg Franc';
$string['LYD'] = 'Libyan Dinar';
$string['MAD'] = 'Moroccan Dirham';
$string['MGF'] = 'Malagasy Franc';
$string['MNT'] = 'Mongolian Tugrik';
$string['MOP'] = 'Macau Pataca';
$string['MRO'] = 'Mauritanian Ouguiya';
$string['MTL'] = 'Maltese Lira';
$string['MUR'] = 'Mauritius Rupee';
$string['MVR'] = 'Maldive Rufiyaa';
$string['MWK'] = 'Malawi Kwacha';
$string['MXP'] = 'Mexican Peso';
$string['MYR'] = 'Malaysian Ringgit';
$string['MZM'] = 'Mozambique Metical';
$string['NGN'] = 'Nigerian Naira';
$string['NIC'] = 'Nicaraguan Cordoba';
$string['NLG'] = 'Dutch Guilder';
$string['NOK'] = 'Norwegian Kroner';
$string['NPR'] = 'Nepalese Rupee';
$string['NZD'] = 'New Zealand Dollar';
$string['OMR'] = 'Omani Rial';
$string['PAB'] = 'Panamanian Balboa';
$string['PEI'] = 'Peruvian Inti';
$string['PGK'] = 'Papua New Guinea Kina';
$string['PHP'] = 'Philippine Peso';
$string['PKR'] = 'Pakistan Rupee';
$string['PLZ'] = 'Polish Zloty';
$string['PTE'] = 'Portuguese Escudo';
$string['PYG'] = 'Paraguay Guarani';
$string['QAR'] = 'Qatari Rial';
$string['ROL'] = 'Romanian Leu';
$string['RWF'] = 'Rwanda Franc';
$string['SAR'] = 'Saudi Arabian Riyal';
$string['SBD'] = 'Solomon Islands Dollar';
$string['SCR'] = 'Seychelles Rupee';
$string['SDP'] = 'Sudanese Pound';
$string['SEK'] = 'Swedish Krona';
$string['SGD'] = 'Singapore Dollar';
$string['SHP'] = 'St. Helena Pound';
$string['SLL'] = 'Sierra Leone Leone';
$string['SOS'] = 'Somali Schilling';
$string['SRG'] = 'Suriname Guilder';
$string['STD'] = 'Sao Tome and Principe Dobra';
$string['SUR'] = 'USSR Rouble';
$string['SVC'] = 'El Salvador Colon';
$string['SYP'] = 'Syrian Potmd';
$string['SZL'] = 'Swaziland Lilangeni';
$string['THB'] = 'Thai Bhat';
$string['TND'] = 'Tunisian Dinar';
$string['TOP'] = 'Tongan Pa\'anga';
$string['TPE'] = 'East Timor Escudo';
$string['TRY'] = 'New Turkish Lira';
$string['TTD'] = 'Trinidad and Tobago Dollar';
$string['TWD'] = 'Taiwan Dollar';
$string['TZS'] = 'Tanzanian Schilling';
$string['UGS'] = 'Uganda Shilling';
$string['USD'] = 'US Dollar';
$string['UYP'] = 'Uruguayan Peso';
$string['VEB'] = 'Venezualan Bolivar';
$string['VND'] = 'Vietnamese Dong';
$string['VUV'] = 'Vanuatu Vatu';
$string['WST'] = 'Samoan Tala';
$string['YDD'] = 'Democratic Yemeni Dinar';
$string['YER'] = 'Yemeni Rial';
$string['YUD'] = 'New Yugoslavia Dinar';
$string['ZAR'] = 'South African Rand';
$string['ZMK'] = 'Zambian Kwacha';
$string['ZRZ'] = 'Zaire Zaire';
$string['ZWD'] = 'Zimbabwe Dollar';

?>

==> moodle-1.7.tgz: moodle/lang/en_utf8/currencies.php <==
<?PHP // $Id: currencies.php,v 1.4.2.1 2006/11/01 09:37:07 moodler Exp $ 
      // currencies.php - created with Moodle 1.7 beta + (2006101003)


$string['AED'] = 'United Arab Emirates Dirham';
$string['AFA'] = 'Afghanistan Afghani';
$string['ALL'] = 'Albanian Lek';
$string['ANG'] = 'Netherlands Antillian Guilder';
$string['AON'] = 'Angolan New Kwanza';
$string['ARA'] = 'Argentinian Nuevo Peso';
$string['AUD'] = 'Australian Dollar';
$string['AWG'] = 'Aruban Florin';
$string['BBD'] = 'Barbados Dollar';
$string['BDT'] = 'Bangladeshi Taka';
$string['BGL'] = 'Bulgarian Lev';
$string['BHD'] = 'Bahraini Dinar';
$string['BIF'] = 'Burundi Franc';
$string['BMD'] = 'Bermudian Dollar';
$string['BND'] = 'Brunei Dollar';
$string['BOB'] = 'Bolivian Boliviano';
$string['BRR'] = 'Brazilian Cruzeiro Real';
$string['BSD'] = 'Bahamian Dollar';
$string['BTN'] = 'Bhutan Ngultrum';
$string['BUK'] = 'Myanmar Kyat';
$string['BWP'] = 'Botswanian Pula';
$string['BZD'] = 'Belize Dollar';
$string['CAD'] = 'Canadian Dollar';
$string['CDZ'] = 'Zaire New Zaire';
$string['CHF'] = 'Swiss Franc';
$string['CLF'] = 'Chilean Unidades de Fomento';
$string['CLP'] = 'Chilean Peso';
$string['CNY'] = 'Yuan (Chinese) Renminbi';
$string['COP'] = 'Colombian Peso';
$string['CRC'] = 'Costa Rican Colon';
$string['CSD'] = 'Serbian Dinar';
$string['CUP'] = 'Cuban Peso';
$string['CVE'] = 'Escudo Caboverdiano';
$string['CYP'] = 'Cyprus Pound';
$string['CZK'] = 'Czech Koruna';
$string['DJF'] = 'Djibouti Franc';
$string['DKK'] = 'Danish Krone';
$string['DOP'] = 'Dominican Peso';
$string['DZD'] = 'Algerian Dinar';
$string['EGP'] = 'Egyptian Pound';
$string['ETB'] = 'Ethiopian Birr';
$string['EUR'] = 'Euro';
$string['FJD'] = 'Fiji Dollar';
$string['FKP'] = 'Falkland Islands Pound';
$string['GBP'] = 'British Pound';
$string['GHC'] = 'Ghanaian Cedi';
$string['GIP'] = 'Gibraltar Pound';
$string['GMD'] = 'Gambian Dalasi';
$string['GNF'] = 'Guinea Franc';
$string['GTQ'] = 'Guatemalan Quetzal';
$string['GWP'] = 'Guinea-Bissau Peso';
$string['GYD'] = 'Guyanan Dollar';
$string['HKD'] = 'Hong Kong Dollar';
$string['HNL'] = 'Honduran Lempira';
$string['HTG'] = 'Haitian Gourde';
$string['HUF'] = 'Hungarian Forint';
$string['IDR'] = 'Indonesian Rupiah';
$string['ILS'] = 'Israeli Shekel';
$string['INR'] = 'Indian Rupee';
$string['IQD'] = 'Iraqi Dinar';
$string['IRR'] = 'Iranian Rial';
$string['ISK'] = 'Iceland Krona';
$string['JMD'] = 'Jamaican Dollar';
$string['JOD'] = 'Jordanian Dinar';
$string['JPY'] = 'Japanese Yen';
$string['KES'] = 'Kenyan Schilling';
$string['KHR'] = 'Cambodian Riel';
$string['KMF'] = 'Comoros Franc';
$string['KPW'] = 'North Korean Won';
$string['KRW'] = 'South Korean Won';
$string['KWD'] = 'Kuwaiti Dinar';
$string['KYD'] = 'Cayman Islands Dollar';
$string['LAK'] = 'Lao Kip';
$string['LBP'] = 'Lebanese Pound';
$string['LKR'] = 'Sri Lanka Rupee';
$string['LRD'] = 'Liberian Dollar';
$string['LSL'] = 'Lesotho Loti';
$string['LYD'] = 'Libyan Dinar';
$string['MAD'] = 'Moroccan Dirham';
$string['MGF'] = 'Malagasy Franc';
$string['MNT'] = 'Mongolian Tugrik';
$string['MOP'] = 'Macau Pataca';
$string['MRO'] = 'Mauritanian Ouguiya';
$string['MTL'] = 'Maltese Lira';
$string['MUR'] = 'Mauritius Rupee';
$string['MVR'] = 'Maldive Rufiyaa';
$string['MWK'] = 'Malawi Kwacha';
$string['MXN'] = 'Mexican New Peso';
$string['MYR'] = 'Malaysian Ringgit';
$string['MZM'] = 'Mozambique Metical';
$string['NGN'] = 'Nigerian Naira';
$string['NIO'] = 'Nicaraguan Cordoba';
$string['NOK'] = 'Norwegian Kroner';
$string['NPR'] = 'Nepalese Rupee';
$string['NZD'] = 'New Zealand Dollar';
$string['OMR'] = 'Omani Rial';
$string['PAB'] = 'Panamanian Balboa';
$string['PEI'] = 'Peruvian Inti';
$string['PGK'] = 'Papua New Guinea Kina';
$string['PHP'] = 'Philippine Peso';
$string['PKR'] = 'Pakistan Rupee';
$string['PLN'] = 'Polish New Zloty';
$string['PYG'] = 'Paraguay Guarani';
$string['QAR'] = 'Qatari Rial';
$string['ROL'] = 'Romanian Leu';
$string['RWF'] = 'Rwanda Franc';
$string['SAR'] = 'Saudi Arabian Riyal';
$string['SBD'] = 'Solomon Islands Dollar';
$string['SCR'] = 'Seychelles Rupee';
$string['SDP'] = 'Sudanese Pound';
$string['SEK'] = 'Swedish Krona';
$string['SGD'] = 'Singapore Dollar';
$string['SHP'] = 'St. Helena Pound';
$string['SKK'] = 'Slovak Koruna';
$string['SLL'] = 'Sierra Leone Leone';
$string['SOS'] = 'Somali Schilling';
$string['SRG'] = 'Suriname Guilder';
$string['STD'] = 'Sao Tome and Principe Dobra';
$string['SUR'] = 'USSR Rouble';
$string['SVC'] = 'El Salvador Colon';
$string['SYP'] = 'Syrian Potmd';
$string['SZL'] = 'Swaziland Lilangeni';
$string['THB'] = 'Thai Bhat';
$string['TND'] = 'Tunisian Dinar';
$string['TOP'] = 'Tongan Pa\'anga';
$string['TPE'] = 'East Timor Escudo';
$string['TRL'] = 'Turkish Lira';
$string['TTD'] = 'Trinidad and Tobago Dollar';
$string['TWD'] = 'Taiwan Dollar';
$string['TZS'] = 'Tanzanian Schilling';
$string['UGS'] = 'Uganda Shilling';
$string['USD'] = 'US Dollar';
$string['UYU'] = 'Uruguayan New Peso';
$string['VEB'] = 'Venezualan Bolivar';
$string['VND'] = 'Vietnamese Dong';
$string['VUV'] = 'Vanuatu Vatu';
$string['WST'] = 'Samoan Tala';
$string['YER'] = 'Yemeni Riyal';
$string['ZAR'] = 'South African Rand';
$string['ZMK'] = 'Zambian Kwacha';
$string['ZWD'] = 'Zimbabwe Dollar';

?>
